# ocx-common: Changelog

All notable changes to the ``ocx-common`` will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to the Python [PEP 440 versioning recommendations](https://peps.python.org/pep-0440/).

### Types of changes
* ``Added`` for new features.
* ``Changed`` for changes in existing functionality.
* ``Deprecated`` for soon-to-be removed features.
* ``Removed`` for now removed features.
* ``Fixed`` for any bug fixes.
* ``Security`` in case of vulnerabilities.


## [1.2.0] - 2025-02-27
bump to [v1.2.0](https://github.com/OCXStandard/ocx-common/releases/tag/v1.2.0)

### Change
* Moved from Poetry package management to uv from Astral


## [1.1.0] - 2025-01-28
bump to [v1.1.0](https://github.com/OCXStandard/ocx-common/releases/tag/v1.1.0)

### Change
* Updated GitHub workflow for python-publish


### Change
* Fixed bug in SchemaDownloader to correctly handling a local file as input
* Updated baselines and tests
* Collected more classes and functions


## [0.1.0] - 2024-12-11
bump to [v1.1.0](https://github.com/OCXStandard/ocx-common/releases/tag/v1.1.0)

### Change
* Initial commit
